==> gnat-1.82-src.tar.gz: gnat-1.82-src/src/ada/a-rtree.h <==
/****************************************************************************/
/*                                                                          */
/*                         GNAT COMPILER COMPONENTS                         */
/*                                                                          */
/*                              A - R T R E E                               */
/*                                                                          */
/*                              C Header File                               */
/*                                                                          */
/*                             $Revision: 1.12 $                            */
/*                                                                          */
/*           Copyright (c) 1992,1993,1994 NYU, All Rights Reserved          */
/*                                                                          */
/* GNAT is free software;  you can  redistribute it  and/or modify it under */
/* terms of the  GNU General Public License as published  by the Free Soft- */
/* ware  Foundation;  either version 2,  or (at your option) any later ver- */
/* sion.  GNAT is distributed in the hope that it will be useful, but WITH- */
/* OUT ANY WARRANTY;  without even the  implied warranty of MERCHANTABILITY */
/* or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License */
/* for  more details.  You should have  received  a copy of the GNU General */
/* Public License  distributed with GNAT;  see file COPYING.  If not, write */
/* to the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA. */
/*                                                                          */
/****************************************************************************/

struct Needed_File_Info
{
  int File_Name;
  int First_Sloc;
  int Last_Sloc;
  int Last_Line;
};

extern int max_gnat_nodes;

extern struct Needed_File_Info *File_Info_Ptr;

extern Tree_Id read_gnat_tree PROTO((char * ));

#if 0
----------------------
-- REVISION HISTORY --
----------------------

----------------------------
revision 1.10
date: Mon Jan 10 00:48:53 1994;  author: dewar
New header
----------------------------
revision 1.11
date: Mon Jan 10 02:09:11 1994;  author: dewar
Undo detabbing operation of 1.11 revision
----------------------------
revision 1.12
date: Sun Jan 16 11:30:35 1994;  author: dewar
Minor reformatting
----------------------------
** New changes after this line and before endif. **
#endif

==> gnat-2.04-src.tar.gz: gnat-2.04-src/src/ada/a-rtree.h <==
/****************************************************************************/
/*                                                                          */
/*                         GNAT COMPILER COMPONENTS                         */
/*                                                                          */
/*                              A - R T R E E                               */
/*                                                                          */
/*                              C Header File                               */
/*                                                                          */
/*                             $Revision: 1.13 $                            */
/*                                                                          */
/*           Copyright (c) 1992,1993,1994 NYU, All Rights Reserved          */
/*                                                                          */
/* GNAT is free software;  you can  redistribute it  and/or modify it under */
/* terms of the  GNU General Public License as published  by the Free Soft- */
/* ware  Foundation;  either version 2,  or (at your option) any later ver- */
/* sion.  GNAT is distributed in the hope that it will be useful, but WITH- */
/* OUT ANY WARRANTY;  without even the  implied warranty of MERCHANTABILITY */
/* or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License */
/* for  more details.  You should have  received  a copy of the GNU General */
/* Public License  distributed with GNAT;  see file COPYING.  If not, write */
/* to the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA. */
/*                                                                          */
/****************************************************************************/

struct Needed_File_Info
{
  int File_Name;
  int First_Sloc;
  int Last_Sloc;
  int Num_Source_Lines;
};

extern int max_gnat_nodes;

extern struct Needed_File_Info *File_Info_Ptr;

extern Tree_Id read_gnat_tree PROTO((char * ));
